# Betty 👵

[![Supported Python versions](https://img.shields.io/pypi/pyversions/betty.svg?logo=python&logoColor=FBE072)](https://pypi.org/project/betty/) 
[![PyPI releases](https://badge.fury.io/py/betty.svg)](https://pypi.org/project/betty/)
[![Code coverage](https://codecov.io/gh/bartfeenstra/betty/branch/0.4.x/graph/badge.svg?token=9sYAd6EQBP)](https://codecov.io/gh/bartfeenstra/betty)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)
[![Recent downloads](https://img.shields.io/pypi/dm/betty.svg)](https://pypi.org/project/betty/)

Betty visualizes and publishes your family history by building interactive, encyclopedia-like genealogy websites out of your
[Gramps](https://gramps-project.org/) and [GEDCOM](https://en.wikipedia.org/wiki/GEDCOM) family trees.

## Demonstration & examples

View the official Betty demonstration site at [bartfeenstra.github.io/betty-demo](https://bartfeenstra.github.io/betty-demo).

View the author's own Betty site at [ancestry.bartfeenstra.com](https://ancestry.bartfeenstra.com).

## Documentation

View the documentation at [https://betty.readthedocs.io/](https://betty.readthedocs.io/0.4.x).

## Sponsors

[Weblate](https://weblate.org/) supports Betty by providing Libre Hosting of their collaborative localization platform.
